"""add todo priority and due date

Revision ID: 004
Revises: 003
Create Date: 2023-11-17

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = '004'
down_revision = '003'
branch_labels = None
depends_on = None


def upgrade():
    # Create priority_level enum type
    with op.batch_alter_table('todos', schema=None) as batch_op:
        # Add priority column
        batch_op.add_column(sa.Column('priority', sa.Enum('low', 'medium', 'high', name='prioritylevel'), nullable=True))
        # Set default values for existing records
        batch_op.execute("UPDATE todos SET priority = 'medium' WHERE priority IS NULL")
        # Make priority not nullable with default
        batch_op.alter_column('priority', nullable=False, server_default='medium')
        
        # Add due_date column
        batch_op.add_column(sa.Column('due_date', sa.DateTime(), nullable=True))


def downgrade():
    # Remove the new columns
    with op.batch_alter_table('todos', schema=None) as batch_op:
        batch_op.drop_column('due_date')
        batch_op.drop_column('priority')
    
    # Drop the enum type
    op.execute('DROP TYPE prioritylevel')